@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -66,6 +66,14 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_en_GB extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
+        final String[] Gulf = new String[] {
+               "Gulf Standard Time",
+               "GTS",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] EMPTY_ZONE = new String[] {
                "",
                "",
@@ -105,9 +113,10 @@ public class TimeZoneNames_en_GB extends TimeZoneNamesBundle {
             { "ART", Europe_Eastern },
             { "ECT", Europe_Central },
             { "Asia/Gaza", Europe_Eastern },
-            { "Asia/Amman", Europe_Eastern },
+            { "Asia/Dubai", Gulf },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
+            { "Asia/Muscat", Gulf },
             { "Europe/Kiev", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
@@ -119,7 +128,6 @@ public class TimeZoneNames_en_GB extends TimeZoneNamesBundle {
             { "Europe/Malta", Europe_Central },
             { "Europe/Sofia", Europe_Eastern },
             { "Europe/Vaduz", Europe_Central },
-            { "Asia/Damascus", Europe_Eastern },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Lisbon", Europe_Western },
@@ -429,7 +437,6 @@ public class TimeZoneNames_en_GB extends TimeZoneNamesBundle {
             { "timezone.excity.Atlantic/Bermuda", "Bermuda" },
             { "timezone.excity.Atlantic/Madeira", "Madeira" },
             { "timezone.excity.Atlantic/Stanley", "Stanley" },
-            { "timezone.excity.Australia/Currie", "Currie" },
             { "timezone.excity.Australia/Darwin", "Darwin" },
             { "timezone.excity.Australia/Hobart", "Hobart" },
             { "timezone.excity.Australia/Sydney", "Sydney" },
@@ -478,7 +485,6 @@ public class TimeZoneNames_en_GB extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/San_Marino", "San Marino" },
             { "timezone.excity.Europe/Simferopol", "Simferopol" },
             { "timezone.excity.Europe/Zaporozhye", "Zaporozhye" },
-            { "timezone.excity.Pacific/Enderbury", "Enderbury" },
             { "timezone.excity.Pacific/Galapagos", "Galapagos" },
             { "timezone.excity.Pacific/Kwajalein", "Kwajalein" },
             { "timezone.excity.Pacific/Marquesas", "Marquesas" },
